@@ -13,7 +13,7 @@ use lib '../..';
 
 use base qw(App::Followme::ConfiguredObject);
 
-our $VERSION = "1.07";
+our $VERSION = "1.08";
 
 use constant COMMAND_START => '<!-- ';
 use constant COMMAND_END => '-->';
@@ -195,6 +195,9 @@ sub get_command {
 
     my $commands = {
                     do => "%%;",
+                    each => "while (my (\$k, \$v) = each %%) {\n" .
+                            "\$self->push_stack({key=>\$k, value=>\$v});",
+                    endeach => "\$self->pop_stack();\n}",
                     for => "foreach (%%) {\n\$self->push_stack(\$_);",
                 	endfor => "\$self->pop_stack();\n}",
                     if => "if (%%) {",
@@ -590,20 +593,19 @@ The following commands are supported in templates:
 The remainder of the line is interpreted as Perl code. For assignments, use
 the set command.
 
-=item if
+=item each
 
-The text until the matching C<endif> is included only if the expression in the
-"if" command is true. If false, the text is skipped. The "if" command can contain
-an C<else>, in which case the text before the "else" is included if the
-expression in the "if" command is true and the text after the "else" is included
-if it is false. You can also place an "elsif" command in the "if" block, which
-includes the following text if its expression is true.
+Repeat the text between the "each" and "endeach" commands for each entry in the
+hash table. The hast table key can be accessed through the variable $key and
+the hash table value through the variable $value. Key-value pairs are returned
+in random order. For example, this code displays the contents of a hash as a
+list:
 
-    <!-- if $highlight eq 'y' -->
-    <em>$text</em>
-    <!-- else -->
-    $text
-    <!-- endif -->
+    <ul>
+    <!-- each %hash -->
+    <li><b>$key</b> $value</li>
+    <!-- endeach -->
+    </ul>
 
 =item for
 
@@ -622,6 +624,21 @@ a list of hashes, and each hash has two entries, name and phone. Then the code
 
 displays the entire phone list.
 
+=item if
+
+The text until the matching C<endif> is included only if the expression in the
+"if" command is true. If false, the text is skipped. The "if" command can contain
+an C<else>, in which case the text before the "else" is included if the
+expression in the "if" command is true and the text after the "else" is included
+if it is false. You can also place an "elsif" command in the "if" block, which
+includes the following text if its expression is true.
+
+    <!-- if $highlight eq 'y' -->
+    <em>$text</em>
+    <!-- else -->
+    $text
+    <!-- endif -->
+
 =item section
 
 If a template contains a section, the text until the endsection command will be
